function delta=nfkbDivDeath_cRelDisconnected(t,x,options,v)
% Uses the nfkb_ode60 with modified CpG derived IKK input
% Uses the Loriaux death model with possible survival
% Uses the modified Tyson Cell Cycle model with rate-determined division
% triggering
%Thresholding on MYC, Bcl2t, CycDt, and Growth 
x=max(x,0);
  % input arguments:
  %    options: ode15s solver options (usually an empty array [])
  %    v : struct of simulation variables
  
%--- Set the Persistent variables
%{
   The sim file calls the ode function once without arguments to reset
    the persistent variables. Once done, it returns.
   nfkb_ode_61(
%}
persistent DELAY_IKB;
persistent DELAY_MON;
persistent MON_DIMS;
persistent IKB_DIMS;

if isempty(t) 
    % Create arrays for inducible transcription delays
    %{ 
     3 columns in each cell array
        1 : array of species concentration
        2 : array of time points for each concentration
        3 : index of last element assigned (iterated in ODE)
    %}
    DELAY_IKB          = cell(v.IKBS,3); 
    DELAY_IKB(:,[1 2]) = {zeros(20000,1)}; %increase if getting errors
    DELAY_IKB(:,3)     = {1};
    
    DELAY_MON          = cell(v.MONOMERS,3);
    DELAY_MON(:,[1 2]) = {zeros(10000,1)}; %increase if getting errors
    DELAY_MON(:,3)     = {1};
    
    % Create Arrays of which dimers induce which monomers or IkBs 
    %{
    This prevents dimers that do not induce txn from becoming repressors
    (when a dimer doesn't induce txn, its inducible rate = 0.  This
    makes the term for that dimer vanish from the numerator, but it
    still remains in the denominator [see the functional form below])
    %}
    MON_DIMS = cell(v.MONOMERS,1);
    IKB_DIMS = cell(v.IKBS,1);
    
    for i = 1:v.MONOMERS
        MON_DIMS{i} = find(v.pdm(1,:,i) > 0);
    end
    
    for i = 1:v.IKBS
        IKB_DIMS{i} = find(v.pdi(7,:,i) > 0);
    end
    
    return; 
end
  
%--- Load Previous Concentrations and set iteration changes to zero
ikb             = zeros(v.IKB_COMP,v.IKBS);
monomer         = zeros(v.MONOMER_COMP,v.MONOMERS);
dimer           = zeros(v.DIMER_COMP,v.DIMERS);
apoptosis       = zeros(v.APOPTOSIS,1);
cellcycle       = zeros(v.CELL_CYCLE,1);


ikb(:)          = x( 1:numel(ikb));
monomer(:)      = x((1+numel(ikb)):(numel(ikb)+numel(monomer)));
dimer(:)        = x((1+numel(ikb)+numel(monomer)):(numel(ikb)+numel(monomer)+numel(dimer)));
apoptosis(:)    = x((1+numel(ikb)+numel(monomer)+numel(dimer)):(numel(ikb)+numel(monomer)+numel(dimer)+numel(apoptosis)));
cellcycle(:)    = x((1+numel(ikb)+numel(monomer)+numel(dimer)+numel(apoptosis)):numel(x));


delta_ikb       = zeros(v.IKB_COMP,v.IKBS);
delta_monomer   = zeros(v.MONOMER_COMP,v.MONOMERS);
delta_dimer     = zeros(v.DIMER_COMP,v.DIMERS);
delta_apoptosis = zeros(v.APOPTOSIS,1);
delta_cellcycle = zeros(v.CELL_CYCLE,1);

%--- Calculate IKK Activity (used in IKK-mediated deg reaction)
%{
 The activity is the product of total IKK and percent active
    Max activity is total IKK (100% active * TOTAL_IKK)
    Basal activity is defined by the v.BASAL_IKK variable
        Typically, we have been using 1% basal activity
%}
if v.PHASE == 1
    ikk_activity = v.BASAL_IKK * v.TOTAL_IKK;
else
     if t+v.START_TIME >= v.SIM_TIME
            ikk_activity = v.CURRENT_IKK(end);    
     else
        % IKK = mx + b ... linear over 1 minute interval 
        start = floor(v.START_TIME+t)+1; % +1 to adjust for t=0 index of 1
        stop  = start + 1;
        

        ikk_activity = ((v.CURRENT_IKK(stop) - v.CURRENT_IKK(start)) ...
            * (t-floor(t)) + v.CURRENT_IKK(start))* v.TOTAL_IKK;
     end
end
   
%---- NFkB Dimer Reactions
%{
    A for loop is used to calculate fluxes for each dimer
    A second, nested, for loop is used to calculate dimer:IkB reactions
%}
for i = 1:v.DIMERS
    if ~v.DIMER_KO(i) %Skip if dimer is Knocked-Out
        continue;
    end

    mon1 = v.pd(1,i); % index# of the 1st monomer
    mon2 = v.pd(2,i); % index# of the 2nd monomer 

    % Association  mon1 + mon2 --> NFkB
    flux1 = v.pd(3,i) * monomer(2,mon1) * monomer(2,mon2); % cytoplasm
    flux2 = v.pd(4,i) * monomer(3,mon1) * monomer(3,mon2); % nucleus

    % Dissociation NFkB --> mon1 + mon2
    flux3 = v.pd(5,i) * dimer(1,i); % cytoplasm
    flux4 = v.pd(6,i) * dimer(2,i); % nucleus

    % Localization NFkB <--> NFkBn
    flux5 = v.pd(7,i) * dimer(1,i); % import          
    flux6 = v.pd(8,i) * dimer(2,i); % export
    
    % NFkB dimer degradation
    flux7 = v.pd(9,i) * dimer(1,i); % cytoplasm    
    flux8 = v.pd(10,i)* dimer(2,i); % nucleus 
    
    % Update concentrations with fluxes
    delta_dimer(1,i)= delta_dimer(1,i)+flux1-flux3-flux5+flux6-flux7; % NFkB cyt
    delta_dimer(2,i)= delta_dimer(2,i)+flux2-flux4+flux5-flux6-flux8; % NFkB nuc
    
    delta_monomer(2,mon1)= delta_monomer(2,mon1) -flux1+flux3; % mon1 cyt
    delta_monomer(2,mon2)= delta_monomer(2,mon2) -flux1+flux3; % mon2 cyt
    
    delta_monomer(3,mon1)= delta_monomer(3,mon1) -flux2+flux4; % mon1 nuc
    delta_monomer(3,mon2)= delta_monomer(3,mon2) -flux2+flux4; % mon2 nuc
        
    % IKB:Dimer Reactions             
    for j = 1:v.IKBS  
        if ~v.IKB_KO(j) %Skip if the IkB is knocked out
            continue;
        end

        % TODO: This needs to get updated with regular expression pattern
        % matching instead of this crazy index calculation. Search the list
        % of species names and find the protein complex of interest.
        cyt = 1+(j*2);    % calculate index for each cyt IkB:NFkB
                          %  The 1st cyt IkB:Dimer is index 3 
        nuc = 1 + cyt;    % calculate index for each nuc IkB:NFkBn
                          %  The corresponding nuc IkB:Dimer is cyt+1

        % Association   IkB + NFkB --> IkB:NFkB
        flux1 = v.pdi(1,i,j) * dimer(1,i) * ikb(2,j); % cytoplasm
        flux2 = v.pdi(2,i,j) * dimer(2,i) * ikb(3,j); % nucleus

        % Dissociation  IkB:NFkB --> IkB + NFkB
        flux3 = v.pdi(3,i,j) * dimer(cyt,i); % cytoplasm
        flux4 = v.pdi(4,i,j) * dimer(nuc,i); % nucleus  

        % Localization.  IkB:NFkB <==> IkB:NFkBn  
        flux5 = v.pdi(5,i,j) * dimer(cyt,i); % import   
        flux6 = v.pdi(6,i,j) * dimer(nuc,i); % export   

        % IKK-mediated IkB degradation.  IkB:NFkB --> NFkB
            % Using an IkB-list parameter
        flux7 = v.pi(12,j) * dimer(cyt,i) * ikk_activity;
        
            % ugly hack for ikbd basal IKK activity only-- Fix later
            % IkBd is not degraded by IKK2 activity, but it is degraded by
            % basal IKK1 activity. Assume here that total IKK1 = IKK2
            if j == 4
                flux7 = v.pi(12,j) * dimer(cyt,i) * v.BASAL_IKK * v.TOTAL_IKK;
            end

        % IKK-indepedent IkB degradation.  IkB:NFkB --> NFkB
            % Using an IkB-list parameter
        flux8 = v.pi(13,j) * dimer(cyt,i); % cytoplasm
        flux9 = v.pi(14,j) * dimer(nuc,i); % nucleus
        
        % IkB-bound NFkB Dimer Deg.  IkB:Dimer --> IkB
        flux10 = v.pd(11,i) * dimer(cyt,i); % cytoplasm
        flux11 = v.pd(12,i) * dimer(nuc,i); % nucleus 
            
        % Update concentrations with fluxes
        delta_dimer(1,i)= delta_dimer(1,i) -flux1+flux3+flux8+flux7;% NFkB
        delta_dimer(2,i)= delta_dimer(2,i) -flux2+flux4+flux9;      % NFkBn
        
        delta_dimer(cyt,i)= delta_dimer(cyt,i) ... % IkB:NFkB
                            +flux1-flux3-flux5+flux6-flux7-flux8-flux10;
        delta_dimer(nuc,i)= delta_dimer(nuc,i) ... % IkB:NFkBn
                            +flux2-flux4+flux5-flux6-flux9-flux11;
                                      
        delta_ikb(2,j)  = delta_ikb(2,j) -flux1+flux3+flux10; % IkB
        delta_ikb(3,j)  = delta_ikb(3,j) -flux2+flux4+flux11; % IkBn 
    end
end
   
%--- Free IKB Reactions
%{
    The first section calculates the const and inducible txn for each IkB
    The second section uses those results and calculates the reaction fluxes
        Matrix math is used for this 2nd section to speed things up.
%}
% Calculate constitutive and inducible txn
ikbtxn = zeros(1,v.IKBS);
for i = 1:v.IKBS
    if ~v.IKB_KO(i) || (v.pi(1,i) == 0) %KO or no const txn
        continue;
    end
    
    if sum(v.pdi(7,:,i)) == 0 % not induced by any dimer
        ikbtxn(1,i) = v.pi(1,i);
        continue;
    end
     %{
     Constitutive and NFkB-induced transcription
       const rate * ( 1 + sum( w*([d]/Kd)^hill)) / ...
                    ( 1 + sum( ([d]/Kd)^hill))  
     p50-Hom is assumed not to bind
    %}
     itxn = v.pi(1,i) * ...
      ((1+sum((v.pdi(7,IKB_DIMS{i},i)) .* (dimer(2,IKB_DIMS{i}) / v.pi(10,i)).^v.pi(9,i)))...
      / (1+sum((dimer(2,IKB_DIMS{i}) / v.pi(10,i)).^v.pi(9,i))));  

    if (v.PHASE == 1) || (v.pi(8,i) == 0) %skip if phase1 or no delay time
        ikbtxn(1,i) = itxn;   
    else  % push itxn to cache array and , if t>delay, calculate previous itxn value  
        if ~any(DELAY_IKB{i,2} == t,1) 
            DELAY_IKB{i,1}(DELAY_IKB{i,3}) = itxn; 
            DELAY_IKB{i,2}(DELAY_IKB{i,3}) = t; 
            DELAY_IKB{i,3} = DELAY_IKB{i,3} + 1;
        end
        % Calculate the concentration of delayed transcription 
        if ( t <= v.pi(8,i) )  % time <= delay so txn is at basal level
            ikbtxn(1,i) =DELAY_IKB{i,1}(1);
        else   % time > delay so interpolate for [mRNA] made at t - delay    

            start = find(DELAY_IKB{i,2}(1:DELAY_IKB{i,3}-1) ...
                    <= (t-v.pi(8,i)),1,'last');
            
            ikbtxn(1,i)=((DELAY_IKB{i,1}(start+1) - DELAY_IKB{i,1}(start)) ...
                       /(DELAY_IKB{i,2}(start+1) - DELAY_IKB{i,2}(start))) ...
                       * ((t-v.pi(8,i)) - DELAY_IKB{i,2}(start)) ...
                       + DELAY_IKB{i,1}(start);  
        end
    end
end

% Calculate fluxes for all IkBs
    delta_ikb(1,:) = delta_ikb(1,:) ... % IkB mRNA
                    + ikbtxn(1,:) ...            % mRNA synthesis
                    - (v.pi(2,:) .* ikb(1,:));   % transcript deg

    delta_ikb(2,:) = delta_ikb(2,:) ... % IkB free in cytoplasm
                    + v.k2(77)*(v.pi(3,:) .* ikb(1,:)) ...% translation
                    - (v.pi(11,:).* ikb(2,:) * ikk_activity)... % IKK deg 
                    - (v.pi(4,:) .* ikb(2,:)) ...% cyt protein deg
                    - (v.pi(6,:) .* ikb(2,:)) ...% nuclear import
                    + (v.pi(7,:) .* ikb(3,:));   % nuclear export

        % ugly hack for ikbd basal IKK activity only-- Fix later
        delta_ikb(2,4) = delta_ikb(2,4) ...
                    + (v.pi(11,4)* ikb(2,4) * ikk_activity) ...
                    - (v.pi(11,4)* ikb(2,4) * v.BASAL_IKK * v.TOTAL_IKK);

    delta_ikb(3,:) = delta_ikb(3,:) ... % IkB free in nucleus
                    - (v.pi(5,:) .* ikb(3,:)) ...% nuc protein deg
                    + (v.pi(6,:) .* ikb(2,:)) ...% nuclear import
                    - (v.pi(7,:) .* ikb(3,:));   % nuclear export
                                
%--- Free NFkB Monomers
% Calculate constitutive and inducible txn
   montxn = zeros(1,v.MONOMERS);
   for i = 1:v.MONOMERS
     if ~v.MONOMER_KO(i) || (v.pm(1,i) == 0) %KO or no const txn
        continue;
     end
     
     if sum(v.pdm(1,:,i)) == 0  % not induced by any dimer
         montxn(1,i) = v.pm(1,i);
         continue;
     end

     itxn = v.pm(1,i) * ...
      ((1 + sum((v.pdm(1,MON_DIMS{i},i)) .* ((dimer(2,MON_DIMS{i})/ v.pm(8,i)).^v.pm(7,i))))...
      / ((1 +sum((dimer(2,MON_DIMS{i}) / v.pm(8,i)).^v.pm(7,i)))));
    
     % no delay in Phase 1 or if delay== 0
     if (v.PHASE == 1) || (v.pm(6,i) == 0)
        montxn(1,i) = itxn; 
        
     else  % Phase 2 and delay_time > 0
        % Push time and  the sum of all mRNA synthesis onto cache array
        if ~any(DELAY_MON{i,2} == t,1)
            DELAY_MON{i,1}(DELAY_MON{i,3}) = itxn; 
            DELAY_MON{i,2}(DELAY_MON{i,3}) = t; 
            DELAY_MON{i,3} = DELAY_MON{i,3} + 1;
        end

        % Calculate the concentration of delayed transcription 
        if ( t <= v.pm(6,i) )  % time <= delay so txn is at basal level
            montxn(1,i) = DELAY_MON{i,1}(1);
        else  % time > delay so interpolate for [mRNA] made at t - delay
            start = find(DELAY_MON{i,2}(1:DELAY_MON{i,3}-1) ...
                    <= (t-v.pm(6,i)),1,'last');
            
            montxn(1,i)=((DELAY_MON{i,1}(start+1) - DELAY_MON{i,1}(start)) ...
                       /(DELAY_MON{i,2}(start+1) - DELAY_MON{i,2}(start))) ...
                       * ((t-v.pm(6,i)) - DELAY_MON{i,2}(start)) ...
                       + DELAY_MON{i,1}(start);
        end
     end
     
   end
  
% Calculate fluxes for all monomers
  delta_monomer(1,:) = delta_monomer(1,:) ... % monomer mRNA
                    + montxn(1,:) ...                % mRNA synthesis
                    - (v.pm(2,:) .* monomer(1,:));   % transcript deg
  
  delta_monomer(2,:) = delta_monomer(2,:) ... % monomer in cyt
                    + v.k2(77)*(v.pm(3,:) .* monomer(1,:)) ...% translation
                    - (v.pm(4,:) .* monomer(2,:));   % protein deg cyt
  
  delta_monomer(3,:) = delta_monomer(3,:) ... % monomer in nuc
                    - (v.pm(5,:) .* monomer(3,:));   % protein deg nuc

% Calculate fluxes for all cell cycle species

  mvol = v.c(1);  % mitochondria compartment volume/cell volume
  % *
  % * Define the Reaction Fluxes
  % *
  apop_flux = zeros(115,1);

  % L + R --(v1)-> L:R
  apop_flux(1) = v.k(1) * apoptosis(1) * apoptosis(2);

  % L:R --(v2)-> L + R
  apop_flux(2) = v.k(2) * apoptosis(3);

  % L:R --(v3)-> DISC (R*)
  apop_flux(3) = v.k(3) * apoptosis(3);

  % flip + DISC --(v4)-> flip:DISC 
  apop_flux(4) = v.k(4) * apoptosis(4) * apoptosis(5);

  % flip:DISC --(v5)-> flip + DISC
  apop_flux(5) = v.k(5) * apoptosis(6);

  % pC8 + DISC --(v6)-> DISC:pC8
  apop_flux(6) = v.k(6) * apoptosis(4) * apoptosis(7);

  % DISC:pC8 --(v7)-> pC8 + DISC
  apop_flux(7) = v.k(7) * apoptosis(8);

  % DISC:pC8 --(v8)-> C8 + DISC
  apop_flux(8) = v.k(8) * apoptosis(8);

  % C8 + BAR --(v9)-> BAR:C8 
  apop_flux(9) = v.k(9) * apoptosis(9) * apoptosis(10);

  % BAR:C8 --(v10)-> C8 + BAR
  apop_flux(10) = v.k(10) * apoptosis(11);

  % pC3 + C8 --(v11)-> pC3:C8
  apop_flux(11) = v.k(11) * apoptosis(9) * apoptosis(12);

  % pC3:C8 --(v12)-> pC3 + C8
  apop_flux(12) = v.k(12) * apoptosis(13);

  % pC3:C8 --(v13)-> C3 + C8
  apop_flux(13) = v.k(13) * apoptosis(13);

  % pC6 + C3 --(v14)-> pC6:C3
  apop_flux(14) = v.k(14) * apoptosis(14) * apoptosis(15);

  % pC6:C3 --(v15)-> pC6 + C3
  apop_flux(15) = v.k(15) * apoptosis(16);

  % pC6:C3 --(v16)-> C6 + C3
  apop_flux(16) = v.k(16) * apoptosis(16);

  % pC8 + C6 --(v17)-> pC8:C6
  apop_flux(17) = v.k(17) * apoptosis(7) * apoptosis(17);

  % pC8:C6 --(v18)-> pC8 + C6
  apop_flux(18) = v.k(18) * apoptosis(18);

  % pC8:C6 --(v19)-> C8 + C6
  apop_flux(19) = v.k(19) * apoptosis(18);

  % XIAP + C3 --(v20)-> XIAP:C3
  apop_flux(20) = v.k(20) * apoptosis(14) * apoptosis(19);

  % XIAP:C3 --(v21)-> XIAP + C3
  apop_flux(21) = v.k(21) * apoptosis(20);

  % XIAP:C3 --(v22)-> XIAP + C3_U
  apop_flux(22) = v.k(22) * apoptosis(20);

  % PARP + C3 --(v23)-> PARP:C3
  apop_flux(23) = v.k(23) * apoptosis(14) * apoptosis(21);

  % PARP:C3 --(v24)-> PARP + C3
  apop_flux(24) = v.k(24) * apoptosis(22);

  % PARP:C3 --(v25)-> CPARP + C3
  apop_flux(25) = v.k(25) * apoptosis(22);

  % Bid + C8 --(v26)-> Bid:C8
  apop_flux(26) = v.k(26) * apoptosis(9) * apoptosis(24);

  % Bid:C8 --(v27)-> Bid + C8
  apop_flux(27) = v.k(27) * apoptosis(25);

  % Bid:C8 --(v28)-> tBid + C8
  apop_flux(28) = v.k(28) * apoptosis(25);

  % tBid + Bcl2c --(v29)-> tBid:Bcl2c 
  apop_flux(29) = v.k(29) * apoptosis(26) * apoptosis(27);

  % tBid:Bcl2c --(v30)-> tBid + Bcl2c 
  apop_flux(30) = v.k(30) * apoptosis(28);

  % Bax + tBid --(v31)-> Bax:tBid
  apop_flux(31) = v.k(31) * apoptosis(26) * apoptosis(29);

  % Bax:tBid --(v32)-> Bax + tBid
  apop_flux(32) = v.k(32) * apoptosis(30);

  % Bax:tBid --(v33)-> aBax + tBid 
  apop_flux(33) = v.k(33) * apoptosis(30);

  % aBax --(v34)-> MBax 
  apop_flux(34) = v.k(34) * apoptosis(31);

  % MBax --(v35)-> aBax 
  apop_flux(35) = v.k(35) * apoptosis(32);

  % MBax + Bcl2 --(v36)-> MBax:Bcl2 
  apop_flux(36) = v.k(36) * apoptosis(32) * apoptosis(33);

  % MBax:Bcl2 --(v37)-> MBax + Bcl2 
  apop_flux(37) = v.k(37) * apoptosis(34);

  % MBax + MBax --(v38)-> Bax2
  apop_flux(38) = v.k(38) * apoptosis(32)^2;

  % Bax2 --(v39)-> MBax + MBax
  apop_flux(39) = v.k(39) * apoptosis(35);

  % Bax2 + Bcl2 --(v40)-> MBax2:Bcl2 
  apop_flux(40) = v.k(40) * apoptosis(33) * apoptosis(35);

  % MBax2:Bcl2 --(v41)-> Bax2 + Bcl2 
  apop_flux(41) = v.k(41) * apoptosis(36);

  % Bax2 + Bax2 --(v42)-> Bax4
  apop_flux(42) = v.k(42) * apoptosis(35)^2;

  % Bax4 --(v43)-> Bax2 + Bax2
  apop_flux(43) = v.k(43) * apoptosis(37);

  % Bax4 + Bcl2 --(v44)-> MBax4:Bcl2 
  apop_flux(44) = v.k(44) * apoptosis(33) * apoptosis(37);

  % MBax4:cl2 --(v45)-> Bax4 + Bcl2 
  apop_flux(45) = v.k(45) * apoptosis(38);

  % Bax4 + Mit0 --(v46)-> Bax4:Mito
  apop_flux(46) = v.k(46) * apoptosis(39) * apoptosis(37);

  % Bax4:Mit0 --(v47)-> Bax4 + Mito
  apop_flux(47) = v.k(47) * apoptosis(40);

  % Bax4:Mit0 --(v48)-> AMito 
  apop_flux(48) = v.k(48) * apoptosis(40);

  % AMito + mCytoC --(v49)-> AMito:mCytoC
  apop_flux(49) = v.k(49) * apoptosis(41) * apoptosis(42);

  % AMito:mCytoC --(v50)-> AMito + mCytoC
  apop_flux(50) = v.k(50) * apoptosis(43);

  % AMito:mCytoC --(v51)-> AMito + ACytoC 
  apop_flux(51) = v.k(51) * apoptosis(43);

  % AMito + mSMac --(v52)-> AMito:mSmac
  apop_flux(52) = v.k(52) * apoptosis(41) * apoptosis(45);

  % AMito:mSMac --(v53)-> AMito + mSmac
  apop_flux(53) = v.k(53) * apoptosis(46);

  % AMito + mSMac --(v54)-> AMito + ASmac 
  apop_flux(54) = v.k(54) * apoptosis(46);

  % ACytoC --(v55)-> cCytoC
  apop_flux(55) = v.k(55) * apoptosis(44);

  % cCytoC --(v56)-> ACytoC
  apop_flux(56) = v.k(56) * apoptosis(48);

  % Apaf + cCytoC --(v57)-> Apaf:cCytoC 
  apop_flux(57) = v.k(57) * apoptosis(50);

  % Apaf:cCytoC --(v58)-> Apaf + cCytoC 
  apop_flux(58) = v.k(58) * apoptosis(48) * apoptosis(49);

  % Apaf:cCytoC --(v59)-> Apaf* + cCytoC 
  apop_flux(59) = v.k(59) * apoptosis(50);

  % Apaf* + Procasp9 --(v60)-> Apoptosome 
  apop_flux(60) = v.k(60) * apoptosis(51) * apoptosis(52);

  % Apoptosome --(v61)-> Apaf* + Procasp9
  apop_flux(61) = v.k(61) * apoptosis(53);

  % Apop + pC3 --(v62)-> Apop:pC3
  apop_flux(62) = v.k(62) * apoptosis(12) * apoptosis(53);

  % Apop:pC3 --(v63)-> Apop + pC3
  apop_flux(63) = v.k(63) * apoptosis(54);

  % Apop:pC3 --(v64)-> Apop + C3 
  apop_flux(64) = v.k(64) * apoptosis(54);

  % ASmac --(v65)-> cSmac
  apop_flux(65) = v.k(65) * apoptosis(47);

  % cSmac --(v66)-> ASmac
  apop_flux(66) = v.k(66) * apoptosis(55);

  % Apop + XIAP --(v67)-> Apop:XIAP 
  apop_flux(67) = v.k(67) * apoptosis(19) * apoptosis(53);

  % Apop:XIAP --(v68)-> Apop + XIAP 
  apop_flux(68) = v.k(68) * apoptosis(56);

  % cSmac + XIAP --(v69)-> cSmac:XIAP 
  apop_flux(69) = v.k(69) * apoptosis(19) * apoptosis(55);

  % cSmac:XIAP --(v70)-> cSmac + XIAP 
  apop_flux(70) = v.k(70) * apoptosis(57);
  
  % null --(v71)-> R
  apop_flux(71) = v.k2(77)*v.k(71);
  
  % R --(v72)-> null
  apop_flux(72) = v.k(72) * apoptosis(2);
  
  % null --(v73)-> flip
  apop_flux(73) = v.k2(77)*v.k(73);
  
  % flip --(v74)-> null
  apop_flux(74) = v.k(74) * apoptosis(5);
  
  % flip:DISC --(v75)-> null
  apop_flux(75) = v.k(75) * apoptosis(6);
  
  % null --(v76)-> pC8
  apop_flux(76) = v.k2(77)*v.k(76);
  
  % pC8 --(v77)-> null
  apop_flux(77) = v.k(77) * apoptosis(7);
  
  % null --(v78)-> BAR
  apop_flux(78) = v.k2(77)*v.k(78);
  
  % BAR --(v79)-> null
  apop_flux(79) = v.k(79) * apoptosis(10);
  
  % BAR:C8 --(v80)-> null
  apop_flux(80) = v.k(80) * apoptosis(11);
  
  % null --(v81)-> Bid
  apop_flux(81) = v.k2(77)*v.k(81);
  
  % Bid --(v82)-> null
  apop_flux(82) = v.k(82) * apoptosis(24);
  
  % Bcl2t --(v83)-> Mcl1
  apop_flux(83) = 246.0455 ;%;so assuming about 900 molecules of Bcl2t
  
  % Bcl2c --(v84)-> null
  apop_flux(84) = v.k(84) * apoptosis(27);
  
  % tBid:Bcl2c --(v85)-> null
  apop_flux(85) = v.k(85) * apoptosis(28);

  % null --(v86)-> Bax
  apop_flux(86) = v.k2(77)*v.k(86);
  
  % Bax --(v87)-> null
  apop_flux(87) = v.k(87) * apoptosis(29);
  
  % Bcl2t --(v88)-> Bcl2 
  if v.activated == 1
    apop_flux(88) = 277.2133;% so assuming about 900 molecules of Bcl2t
  end
  % Bcl2 --(v89)-> null
  apop_flux(89) = v.k(89) * apoptosis(33);
  
  % Baxm:Bcl2 --(v90)-> null
  apop_flux(90) = v.k(90) * apoptosis(34);
  
  % Bax2:Bcl2 --(v91)-> null
  apop_flux(91) = v.k(91) * apoptosis(36);
  
  % Bax4:Bcl2 --(v92)-> null
  apop_flux(92) = v.k(92) * apoptosis(38);
  
  % AMito --(v93)-> Mito
  apop_flux(93) = v.k(93) * apoptosis(41);
  
  % Apaf* --(v94)-> Apaf
  apop_flux(94) = v.k(94) * apoptosis(51);
  
  % null --(v95)-> XIAP
  apop_flux(95) = v.k2(77)*v.k(95);
  
  % XIAP --(v96)-> null
  apop_flux(96) = v.k(96) * apoptosis(19);
  
  % null --(v97)-> mSmac
  apop_flux(97) = v.k2(77)*v.k(97);
  
  % mSmac --(v98)-> null
  apop_flux(98) = v.k(98) * apoptosis(45);
  
  % cSmac --(v99)-> null
  apop_flux(99) = v.k(99) * apoptosis(55);
  
  % cSmac:XIAP --(v100)-> null
  apop_flux(100) = v.k(100) * apoptosis(57);
  
  % null --(v101)-> pC3
  apop_flux(101) = v.k2(77)*v.k(101);
  
  % pC3 --(v102)-> null
  apop_flux(102) = v.k(102) * apoptosis(12);
  
  % C3_U --(v103)-> null
  apop_flux(103) = v.k(103) * apoptosis(58);
  
  % null --(v104)-> pC6
  apop_flux(104) = v.k2(77)*v.k(104);
  
  % pC6 --(v105)-> null
  apop_flux(105) = v.k(105) * apoptosis(15);
  
  % C6 --(v106)-> null
  apop_flux(106) = v.k(106) * apoptosis(17);
  
  % Apop:XIAP --(v107)-> Apop
  apop_flux(107) = v.k(107) * apoptosis(56);
  
  % null --(v108)-> Parp
  apop_flux(108) = v.k2(77)*v.k(108);
  
  % Parp --(v109)-> null
  apop_flux(109) = v.k(109) * apoptosis(21);
  
  % cParp --(v110)-> null
  apop_flux(110) = v.k(110) * apoptosis(23);

  % null --(v111)-> L
  %apop_flux(111) = v.k2(77)*v.k(111);
 
  % L --(v112)-> null
  %apop_flux(112) = v.k(112) * apoptosis(1);

  % null --(v113)-> mCytoC
  apop_flux(113) = v.k2(77)*v.k(113);

  % mCytoC --(v114)-> null
  apop_flux(114) = v.k(114) * apoptosis(42);

  % cCytoC --(v115)-> null
  apop_flux(115) = v.k(115) * apoptosis(48);
  
  %decay of the ligand
  %apop_flux(116) = 0.000174 * apoptosis(1);

  % * 
  % * Define the derivatives
  % *

  %  x1    L  % assume that this is a constant source of death caused by
  %  lack of survival signaling and does not wash out or degrade. Basically
  %  this is a constant that must be countermanded by survival signals via
  %  Bcl-2 synthesis
  delta_apoptosis(1) = 0;%-0.000174 * apoptosis(1);%-apop_flux(1) + apop_flux(2) + apop_flux(111) - apop_flux(112);

  %  x2    R
  delta_apoptosis(2) = -apop_flux(1) + apop_flux(2) + apop_flux(71) - apop_flux(72);

  %  x3    L:R
  delta_apoptosis(3) = apop_flux(1) - apop_flux(2) - apop_flux(3) ;

  %  x4    DISC
  delta_apoptosis(4) = apop_flux(3) - apop_flux(4) + apop_flux(5) - apop_flux(6) + apop_flux(7) + apop_flux(8);

  %  x5    flip
  delta_apoptosis(5) = -apop_flux(4) + apop_flux(5) + apop_flux(73) - apop_flux(74);

  %  x6    flip:DISC
  delta_apoptosis(6) = apop_flux(4) - apop_flux(5) - apop_flux(75);

  %  x7    pC8
  delta_apoptosis(7) = -apop_flux(6) + apop_flux(7) - apop_flux(17) + apop_flux(18) + apop_flux(76) - apop_flux(77);

  %  x8    DISC:pC8
  delta_apoptosis(8) = apop_flux(6) - apop_flux(7) - apop_flux(8) ;

  %  x9    C8
  delta_apoptosis(9) = apop_flux(8) - apop_flux(9) + apop_flux(10) - apop_flux(11) + apop_flux(12) + apop_flux(13) + apop_flux(19) - apop_flux(26) + apop_flux(27) + apop_flux(28) ;

  %  x10    Bar
  delta_apoptosis(10) = -apop_flux(9) + apop_flux(10) + apop_flux(78) - apop_flux(79);

  %  x11    Bar:C8
  delta_apoptosis(11) = apop_flux(9) - apop_flux(10) - apop_flux(80);

  %  x12    pC3
  delta_apoptosis(12) = -apop_flux(11) + apop_flux(12) - apop_flux(62) + apop_flux(63) + apop_flux(101) - apop_flux(102) ;

  %  x13    C8:pC3
  delta_apoptosis(13) = apop_flux(11) - apop_flux(12) - apop_flux(13) ;

  %  x14    C3
  delta_apoptosis(14) = apop_flux(13) - apop_flux(14) + apop_flux(15) + apop_flux(16) - apop_flux(20) + apop_flux(21) - apop_flux(23) + apop_flux(24) + apop_flux(25) + apop_flux(64) ;

  %  x15    pC6
  delta_apoptosis(15) = -apop_flux(14) + apop_flux(15) + apop_flux(104) - apop_flux(105);

  %  x16    C3:pC6
  delta_apoptosis(16) = apop_flux(14) - apop_flux(15) - apop_flux(16) ;

  %  x17    C6
  delta_apoptosis(17) = apop_flux(16) - apop_flux(17) + apop_flux(18) + apop_flux(19) - apop_flux(106);

  %  x18    C6:pC8
  delta_apoptosis(18) = apop_flux(17) - apop_flux(18) - apop_flux(19) ;

  %  x19    XIAP
  delta_apoptosis(19) = -apop_flux(20) + apop_flux(21) + apop_flux(22) - apop_flux(67) + apop_flux(68) - apop_flux(69) + apop_flux(70) + apop_flux(95) - apop_flux(96);

  %  x20    XIAP:C3
  delta_apoptosis(20) = apop_flux(20) - apop_flux(21) - apop_flux(22) ;

  %  x21    PARP
  delta_apoptosis(21) = -apop_flux(23) + apop_flux(24) + apop_flux(108) - apop_flux(109);

  %  x22    C3:PARP
  delta_apoptosis(22) = apop_flux(23) - apop_flux(24) - apop_flux(25) ;

  %  x23    CPARP
  delta_apoptosis(23) = apop_flux(25) - apop_flux(110);

  %  x24    Bid
  delta_apoptosis(24) = -apop_flux(26) + apop_flux(27) + apop_flux(81) - apop_flux(82);

  %  x25    C8:Bid
  delta_apoptosis(25) = apop_flux(26) - apop_flux(27) - apop_flux(28) ;

  %  x26    tBid
  delta_apoptosis(26) = apop_flux(28) - apop_flux(29) + apop_flux(30) - apop_flux(31) + apop_flux(32) + apop_flux(33);

  %  x27    Mcl1
  delta_apoptosis(27) = -apop_flux(29) + apop_flux(30) + apop_flux(83) - apop_flux(84);

  %  x28    Bcl2c:tBid
  delta_apoptosis(28) = + apop_flux(29) - apop_flux(30) - apop_flux(85);

  %  x29    Bax
  delta_apoptosis(29) = -apop_flux(31) + apop_flux(32) + apop_flux(86) - apop_flux(87);

  %  x30    tBid:Bax
  delta_apoptosis(30) = apop_flux(31) - apop_flux(32) - apop_flux(33) ;

  %  x31    Bax*
  delta_apoptosis(31) = apop_flux(33) - apop_flux(34) + apop_flux(35) ;

  %  x32    Baxm
  delta_apoptosis(32) = apop_flux(34) - apop_flux(35) -1/mvol*apop_flux(36) + apop_flux(37) -1/mvol*2*apop_flux(38) +2*apop_flux(39) ;

  %  x33    Bcl2
  delta_apoptosis(33) = -1/mvol*apop_flux(36) + apop_flux(37) -1/mvol*apop_flux(40) + apop_flux(41) -1/mvol*apop_flux(44) + apop_flux(45) + apop_flux(88) - apop_flux(89);

  %  x34    Baxm:Bcl2
  delta_apoptosis(34) = 1/mvol*apop_flux(36) - apop_flux(37) - apop_flux(90);

  %  x35    Bax2
  delta_apoptosis(35) = 1/mvol*apop_flux(38) - apop_flux(39) -1/mvol*apop_flux(40) + apop_flux(41) -2/mvol*apop_flux(42) +2*apop_flux(43) ;

  %  x36    Bax2:Bcl2
  delta_apoptosis(36) = 1/mvol*apop_flux(40) - apop_flux(41) - apop_flux(91);

  %  x37    Bax4
  delta_apoptosis(37) = 1/mvol*apop_flux(42) - apop_flux(43)-1/mvol*apop_flux(44) + apop_flux(45) -1/mvol*apop_flux(46) + apop_flux(47) ;

  %  x38    Bax4:Bcl2
  delta_apoptosis(38) = 1/mvol*apop_flux(44) - apop_flux(45) - apop_flux(92);

  %  x39    M
  delta_apoptosis(39) = -1/mvol*apop_flux(46) + apop_flux(47) + apop_flux(93);

  %  x40    Bax4:M
  delta_apoptosis(40) = 1/mvol*apop_flux(46) - apop_flux(47) - apop_flux(48) ;

  %  x41    AMito
  delta_apoptosis(41) = apop_flux(48) -1/mvol*apop_flux(49) + apop_flux(50) + apop_flux(51) -1/mvol*apop_flux(52) + apop_flux(53) + apop_flux(54) - apop_flux(93);

  %  x42    mCytoC
  delta_apoptosis(42) = -1/mvol*apop_flux(49) + apop_flux(50) + apop_flux(113) - apop_flux(114);

  %  x43    AMito:mCytoC
  delta_apoptosis(43) = 1/mvol*apop_flux(49) - apop_flux(50) - apop_flux(51) ;

  %  x44    ACytoC
  delta_apoptosis(44) = apop_flux(51) - apop_flux(55) + apop_flux(56) ;

  %  x45    mSmac
  delta_apoptosis(45) = -1/mvol*apop_flux(52) + apop_flux(53) + apop_flux(97) - apop_flux(98);

  %  x46    AMito:mSmac
  delta_apoptosis(46) = 1/mvol*apop_flux(52) - apop_flux(53) - apop_flux(54) ;

  %  x47    ASmac
  delta_apoptosis(47) = apop_flux(54) - apop_flux(65) + apop_flux(66) ;

  %  x48    CytoC
  delta_apoptosis(48) = apop_flux(55) - apop_flux(56) - apop_flux(58) + apop_flux(59) + apop_flux(57) - apop_flux(115);

  %  x49    Apaf
  delta_apoptosis(49) = -apop_flux(58) + apop_flux(59) + apop_flux(94);

  %  x50    Apaf:CytoC
  delta_apoptosis(50) = apop_flux(58) - apop_flux(59) - apop_flux(57) ;

  %  x51    Apaf*
  delta_apoptosis(51) = apop_flux(57) - apop_flux(60) + apop_flux(61) - apop_flux(94);

  %  x52    pC9
  delta_apoptosis(52) = -apop_flux(60) + apop_flux(61) ;

  %  x53    Apop
  delta_apoptosis(53) = apop_flux(60) - apop_flux(61) - apop_flux(62) + apop_flux(63) + apop_flux(64) - apop_flux(67) + apop_flux(68) + apop_flux(107);

  %  x54    Apop:pC3
  delta_apoptosis(54) = apop_flux(62) - apop_flux(63) - apop_flux(64) ;

  %  x55    cSmac
  delta_apoptosis(55) = apop_flux(65) - apop_flux(66) - apop_flux(69) + apop_flux(70) - apop_flux(99);

  %  x56    Apop:XIAP
  delta_apoptosis(56) = apop_flux(67) - apop_flux(68) - apop_flux(107);

  %  x57    cSmac:XIAP
  delta_apoptosis(57) = apop_flux(69) - apop_flux(70) - apop_flux(100);

  %  x58    C3_Ub
  delta_apoptosis(58) = apop_flux(22) - apop_flux(103);
 
% Lets calculate everything for the cell cycle model

    PP1A = v.k2(44)/(v.k2(43)*(v.k2(45)*(cellcycle(1)+cellcycle(4))+v.k2(46)*cellcycle(2))+1);
    V2 = v.k2(28)*cellcycle(10)+v.k2(26)*(1-cellcycle(7))+v.k2(27)*cellcycle(7);
    V4 = v.k2(51)*(v.k2(54)*cellcycle(1)+v.k2(53)*cellcycle(2)+v.k2(52)*cellcycle(4));
    V6 = v.k2(30)+v.k2(31)*(v.k2(34)*cellcycle(1)+v.k2(33)*cellcycle(2)+v.k2(32)*cellcycle(4));
    V8 = ((v.k2(19)*(cellcycle(1)+cellcycle(4))+v.k2(20)*cellcycle(2))*v.k2(15))/(cellcycle(4)+cellcycle(12)+v.k2(18))+v.k2(14);

    CycDActivity =  0;  
    MycActivity = 0;

    if v.activated == 1
        if v.LOOKFOR == 1  % cell cycle (just want to divide)
            CycDActivity =  0.5;
            MycActivity = 0.9;
        end
    end
    expn=2; %2.71828;   %Hill exponent

    GrowthMultiplier = ((cellcycle(24)/v.GROWTH_THRESHOLD)^expn/(1+(cellcycle(24)/v.GROWTH_THRESHOLD)^expn));
    
    
        
    %Rate equations
    cellcycle_flux = zeros(57,1);
    cellcycle_flux(1)= v.k2(79)*cellcycle(5);  %CyCDt degradation
    cellcycle_flux(2)= v.k2(81)*cellcycle(6);  %Bcl2t degradation
    cellcycle_flux(3)= v.k2(9)*cellcycle(9);    %CD degredation
    cellcycle_flux(4)= v.k2(9)*cellcycle(3);    %CycD degredation
    cellcycle_flux(5)= v.k2(16)*cellcycle(16)*cellcycle(4);
    cellcycle_flux(6)= v.k2(16)*cellcycle(16)*cellcycle(1); 
    cellcycle_flux(7)= v.k2(10)*cellcycle(16)*cellcycle(3); % CD binding to P27
    cellcycle_flux(8)= v.k2(11)*cellcycle(9);
    cellcycle_flux(9)= v.k2(22)*cellcycle(10)*cellcycle(1);
    cellcycle_flux(10)= v.k2(22)*cellcycle(10)*cellcycle(8);
    cellcycle_flux(11)= v.k2(17)*cellcycle(12);
    cellcycle_flux(12)= v.k2(17)*cellcycle(8);
    cellcycle_flux(13)= V8*cellcycle(12);
    cellcycle_flux(14)= V8*cellcycle(4);
    cellcycle_flux(15)= V6*cellcycle(16);
    cellcycle_flux(16)= V6*cellcycle(12);
    cellcycle_flux(17)= V6*cellcycle(9);
    cellcycle_flux(18)= V6*cellcycle(8);
    cellcycle_flux(19)= V2*cellcycle(2);
    if cellcycle(7) <= 1
        cellcycle_flux(20)= ((v.k2(47)+v.k2(48)*cellcycle(10))*(1-cellcycle(7)))/(v.k2(49)-cellcycle(7)+1);
    else
        cellcycle_flux(20) = 0;
    end
    cellcycle_flux(21)= (V4*cellcycle(7))/(v.k2(50)+cellcycle(7));
    cellcycle_flux(22)= v.k2(56)*cellcycle(17);
    cellcycle_flux(23)= (v.k2(57)*cellcycle(2)*(1-cellcycle(14)))/(v.k2(59)-cellcycle(14)+1);
    cellcycle_flux(24)= (v.k2(58)*cellcycle(17)*cellcycle(14))/(v.k2(60)+cellcycle(14));
    cellcycle_flux(25)= v.k2(63)*cellcycle(11);
    cellcycle_flux(26)= (v.k2(64)*cellcycle(14)*(cellcycle(11)-cellcycle(10)))/(v.k2(66)-cellcycle(10)+cellcycle(11));
    cellcycle_flux(27)= (v.k2(65)*cellcycle(10))/(v.k2(67)+cellcycle(10));
    cellcycle_flux(28)= v.k2(63)*cellcycle(10);
    % E2F-Rb ->E2F+Rb based on CycA, CycD, CycB, and CycE
    cellcycle_flux(29)= cellcycle(22)*( v.k2(40)*( (cellcycle(3)+cellcycle(9)) * v.k2(36) + v.k2(39)*cellcycle(1) + v.k2(38)*cellcycle(2) + v.k2(37)*cellcycle(4) ) );
    % p-E2F-Rb -> p-E2F+Rb based on CycA, CycD, CycB, and CycE
    cellcycle_flux(30)= cellcycle(23)*( v.k2(40)*( (cellcycle(3)+cellcycle(9)) * v.k2(36) + v.k2(39)*cellcycle(1) + v.k2(38)*cellcycle(2) + v.k2(37)*cellcycle(4) ) );
    %V(31) (GM growth) requires that we check a condition
        numerator= cellcycle(21)+cellcycle(22)+cellcycle(23);  %ACTIVE RB
        denominator = numerator+cellcycle(18); %TOTAL RB
    
    %GM growth (biosynthesis of ribosomes and all necessary machinery)  
    v.GMgrowth = (2.8*cellcycle(15)^2)*exp(-0.14*cellcycle(15)^2);%max(0,2.5*cellcycle(15)^2-0.6*cellcycle(15)^3);  % surface area growth and volume based decay
    if numerator/denominator < 0.8  %Growth depends on inactivation of Rb and myc availability
        cellcycle_flux(31)= v.k2(74)*(0.01+0.99*GrowthMultiplier*v.GMgrowth);  % non-linear growth
    else
        cellcycle_flux(31)=v.k2(74)*0.01; % basal growth to maintain size
    end
    %GM decay
    cellcycle_flux(32)= v.k2(75)*cellcycle(13);
    %Mass growth based on GM
    cellcycle_flux(33)= v.k2(77)*v.k2(76)*cellcycle(13);
    % Mass decay
    cellcycle_flux(55) = v.k2(84)*cellcycle(15); 
    
    cellcycle_flux(34)= v.k2(78)*CycDActivity;  %CycDt synthesis
   
    cellcycle_flux(35)= v.k2(77)*(v.k2(61)+v.k2(62)*cellcycle(2));

    if cellcycle(15) > 0.5
        cellcycle_flux(36)= v.k2(77)*v.k2(21)*cellcycle(19)*max(0,(GrowthMultiplier*(cellcycle_flux(33)-cellcycle_flux(55))*30));
    else
        cellcycle_flux(36)= 0;
    end
    cellcycle_flux(37)= v.k2(77)*v.k2(55);
    cellcycle_flux(38)= v.k2(77)*(v.k2(12)+v.k2(13)*cellcycle(19));
    
    %%%%%%%%%%%%% CycD transcript dependent synthesis of CycD  %%%%
    cellcycle_flux(39)= v.k2(77)*v.k2(8)*cellcycle(5);
    cellcycle_flux(53)= v.k2(82)*cellcycle(25);  %myc synthesis
    cellcycle_flux(54) = v.k2(83)*cellcycle(24);  % myc degradation
    
    %%%%%%%%%%%%% Myc transcript Synthesis %%%%%%%%%%%%%%%%%%%%%%%%
    %if dimer(2,4)> v.MYC_THRESHOLD|| dimer(2,2) > v.MYC_THRESHOLD
        cellcycle_flux(56)= v.k2(85)*MycActivity;  %Myct synthesis
   % else
    %    cellcycle_flux(56) = 0;
    %end
    % myc transcript deg
    cellcycle_flux(57)=v.k2(86)*cellcycle(25);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    cellcycle_flux(40)= v.k2(77)*v.k2(29);
           cj=cellcycle(2)/v.k2(25);
          
    cellcycle_flux(42)= v.k2(77)*((v.k2(24)*(cj*cj))/((cj*cj)+1)+v.k2(23));
    cellcycle_flux(43)= cellcycle(21)*( v.k2(40)*( (cellcycle(3)+cellcycle(9)) * v.k2(36) + v.k2(39)*cellcycle(1) + v.k2(38)*cellcycle(2) + v.k2(37)*cellcycle(4) ) );
    cellcycle_flux(44)= cellcycle(18)*(v.k2(41)*(v.k2(44)-PP1A)+v.k2(42)*PP1A);
    cellcycle_flux(45)= cellcycle(22)* v.k2(73);
    cellcycle_flux(46)= cellcycle(19)*(v.k2(70)+v.k2(71)*(cellcycle(1)+cellcycle(2)));
    cellcycle_flux(47)= cellcycle(20)*v.k2(69);
    cellcycle_flux(48)= cellcycle(19)*cellcycle(21)*v.k2(72);
    cellcycle_flux(49)= cellcycle(23)*v.k2(73);
    cellcycle_flux(50)= cellcycle(21)*cellcycle(20)*v.k2(72);
    cellcycle_flux(51)= cellcycle(23)*v.k2(69);
    cellcycle_flux(52)= cellcycle(22)*(v.k2(70)+v.k2(71)*(cellcycle(1)+cellcycle(2)));
    

    

    

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    cellcycle_flux(40)= v.k2(77)*v.k2(29);
           cj=cellcycle(2)/v.k2(25);
          
    cellcycle_flux(42)= v.k2(77)*((v.k2(24)*(cj*cj))/((cj*cj)+1)+v.k2(23));
    cellcycle_flux(43)= cellcycle(21)*( v.k2(40)*( (cellcycle(3)+cellcycle(9)) * v.k2(36) + v.k2(39)*cellcycle(1) + v.k2(38)*cellcycle(2) + v.k2(37)*cellcycle(4) ) );
    cellcycle_flux(44)= cellcycle(18)*(v.k2(41)*(v.k2(44)-PP1A)+v.k2(42)*PP1A);
    cellcycle_flux(45)= cellcycle(22)* v.k2(73);
    cellcycle_flux(46)= cellcycle(19)*(v.k2(70)+v.k2(71)*(cellcycle(1)+cellcycle(2)));
    cellcycle_flux(47)= cellcycle(20)*v.k2(69);
    cellcycle_flux(48)= cellcycle(19)*cellcycle(21)*v.k2(72);
    cellcycle_flux(49)= cellcycle(23)*v.k2(73);
    cellcycle_flux(50)= cellcycle(21)*cellcycle(20)*v.k2(72);
    cellcycle_flux(51)= cellcycle(23)*v.k2(69);
    cellcycle_flux(52)= cellcycle(22)*(v.k2(70)+v.k2(71)*(cellcycle(1)+cellcycle(2)));
    
    % 1 CycA
    delta_cellcycle(1)= cellcycle_flux(36)+cellcycle_flux(12)+cellcycle_flux(18)-cellcycle_flux(9)-cellcycle_flux(6);
    % 2 CycB
    delta_cellcycle(2)= cellcycle_flux(42)-cellcycle_flux(19);
    % 3 CycD
    delta_cellcycle(3)= cellcycle_flux(39)+cellcycle_flux(17)+cellcycle_flux(8)-cellcycle_flux(7)-cellcycle_flux(4);
    % 4 CycE
    delta_cellcycle(4)= cellcycle_flux(38)+cellcycle_flux(11)+cellcycle_flux(16)-cellcycle_flux(14)-cellcycle_flux(5);
    % 5 CycDt
    delta_cellcycle(5)= cellcycle_flux(34)-cellcycle_flux(1);
    % 6 Bcl2t
    delta_cellcycle(6)= cellcycle_flux(41)-cellcycle_flux(2);
    % 7 Cdh1
    delta_cellcycle(7)= cellcycle_flux(20)-cellcycle_flux(21);
    % 8 CA
    delta_cellcycle(8)= cellcycle_flux(6)-cellcycle_flux(12)-cellcycle_flux(18)-cellcycle_flux(10);
    % 9 CD
    delta_cellcycle(9)= cellcycle_flux(7)-cellcycle_flux(8)-cellcycle_flux(17)-cellcycle_flux(3);
    % 10 CDc20
    delta_cellcycle(10)= cellcycle_flux(26)-cellcycle_flux(27)-cellcycle_flux(28);
    % 11 CDc20T
    delta_cellcycle(11)= cellcycle_flux(35)-cellcycle_flux(25);
    % 12 CE
    delta_cellcycle(12)= cellcycle_flux(5)-cellcycle_flux(11)-cellcycle_flux(13)-cellcycle_flux(16);
    % 13 GM (General Machinery)
    delta_cellcycle(13)= cellcycle_flux(31)-cellcycle_flux(32);
    % 14 IEP
    delta_cellcycle(14)= cellcycle_flux(23)-cellcycle_flux(24);
    % 15 Mass
    delta_cellcycle(15)= cellcycle_flux(33)-cellcycle_flux(55);
    % 16 P27
    delta_cellcycle(16)= cellcycle_flux(40)+cellcycle_flux(3)+cellcycle_flux(8)-cellcycle_flux(15)-cellcycle_flux(5)-cellcycle_flux(6)-cellcycle_flux(7)+cellcycle_flux(11)+cellcycle_flux(12)+cellcycle_flux(13)+cellcycle_flux(10);
    % 17 PPX
    delta_cellcycle(17)= cellcycle_flux(37)-cellcycle_flux(22);
    % 18 pp-RB
    delta_cellcycle(18)= cellcycle_flux(29)+cellcycle_flux(30)+cellcycle_flux(43)-cellcycle_flux(44);
    % 19 E2F
    delta_cellcycle(19)= cellcycle_flux(29)+cellcycle_flux(45)+cellcycle_flux(47)-cellcycle_flux(46)-cellcycle_flux(48);
    % 20 p-E2F
    delta_cellcycle(20)= cellcycle_flux(30)+cellcycle_flux(49)+cellcycle_flux(46)-cellcycle_flux(47)-cellcycle_flux(50);
    % 21 Rb
    delta_cellcycle(21)= cellcycle_flux(44)+cellcycle_flux(45)+cellcycle_flux(49)-cellcycle_flux(48)-cellcycle_flux(50)-cellcycle_flux(43);
    % 22 E2F-Rb
    delta_cellcycle(22)= cellcycle_flux(51)+cellcycle_flux(48)-cellcycle_flux(52)-cellcycle_flux(29)-cellcycle_flux(45);
    % 23 p-E2F-Rb
    delta_cellcycle(23)= cellcycle_flux(52)+cellcycle_flux(50)-cellcycle_flux(51)-cellcycle_flux(30)-cellcycle_flux(49);
    % 24 Myc
    delta_cellcycle(24)= cellcycle_flux(53)-cellcycle_flux(54);
    % 25 Myc transcript
    delta_cellcycle(25)=  cellcycle_flux(56)-cellcycle_flux(57);

    %--- Save concentrations for the next time step
    delta  = [delta_ikb(:);delta_monomer(:);delta_dimer(:);delta_apoptosis(:);delta_cellcycle(:)];


end